# {{name}}

### Setup locally for development

```shell
make develop
```

### Install for deployment

```shell
make install
```

### Launch a Visdom server

```shell
make server
```

### Train a model

```shell
make train/default
```
